<?php

/**
 * Exception indicating user not found by authsource.
 *
 * @author Thomas Graff <thomas.graff@uninett.no>
 * @package SimpleSAMLphp_base
 *
 */
class SimpleSAML_Error_UserNotFound extends SimpleSAML_Error_User
{

}
